Module compression

Module compression 

Compression module providing Brotli and Gzip compression.

Structs

CompressionOptions
Compression options
CompressionResult
Result of a compression operation

Enums

CompressionAlgorithm
Supported compression algorithms

Constants

MAX_COMPRESSION_RATIO
Maximum expansion accepted by the default in-memory decompressor.
MAX_DECOMPRESSED_SIZE
Maximum output produced by one in-memory decompression operation.

Functions

compress
Compress data using the specified algorithm
decompress
Decompress data using the specified algorithm
decompress_bounded
Decompress with an explicit absolute output bound.
decompress_exact
Decompress into an authenticated expected size while retaining global and ratio bounds. The expected size is checked before any output allocation.
decompress_with_limits
Decompress with explicit output and expansion bounds.
deserialize_with_header
Deserialize compression result with header
serialize_with_header
Serialize compression result with header