pub fn inspect_fused(data: &[u8]) -> Result<FusedShellInfo>Expand description
Inspect a serialized fused shell envelope without a key.
pub fn inspect_fused(data: &[u8]) -> Result<FusedShellInfo>Inspect a serialized fused shell envelope without a key.