Compression module providing Brotli and Gzip compression.
Structs
- Compression
Options - Compression options
- Compression
Result - Result of a compression operation
Enums
- Compression
Algorithm - Supported compression algorithms
Constants
- MAX_
COMPRESSION_ RATIO - Maximum expansion accepted by the default in-memory decompressor.
- MAX_
DECOMPRESSED_ SIZE - Maximum output produced by one in-memory decompression operation.
Functions
- compress
- Compress data using the specified algorithm
- decompress
- Decompress data using the specified algorithm
- decompress_
bounded - Decompress with an explicit absolute output bound.
- decompress_
exact - Decompress into an authenticated expected size while retaining global and ratio bounds. The expected size is checked before any output allocation.
- decompress_
with_ limits - Decompress with explicit output and expansion bounds.
- deserialize_
with_ header - Deserialize compression result with header
- serialize_
with_ header - Serialize compression result with header